"use strict";
/*
 * Copyright 2016 Palantir Technologies, Inc. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.KeyComboTag = exports.KeyComboTagInternal = exports.DISPLAY_ALIASES = void 0;
const tslib_1 = require("tslib");
const classnames_1 = tslib_1.__importDefault(require("classnames"));
const React = tslib_1.__importStar(require("react"));
const icons_1 = require("@blueprintjs/icons");
const common_1 = require("../../common");
const icon_1 = require("../icon/icon");
const hotkeyParser_1 = require("./hotkeyParser");
const KEY_ICONS = {
    alt: { icon: React.createElement(icons_1.KeyOption, null), iconTitle: "Alt/Option key", isMacOnly: true },
    arrowdown: { icon: React.createElement(icons_1.ArrowDown, null), iconTitle: "Down key" },
    arrowleft: { icon: React.createElement(icons_1.ArrowLeft, null), iconTitle: "Left key" },
    arrowright: { icon: React.createElement(icons_1.ArrowRight, null), iconTitle: "Right key" },
    arrowup: { icon: React.createElement(icons_1.ArrowUp, null), iconTitle: "Up key" },
    cmd: { icon: React.createElement(icons_1.KeyCommand, null), iconTitle: "Command key", isMacOnly: true },
    ctrl: { icon: React.createElement(icons_1.KeyControl, null), iconTitle: "Control key", isMacOnly: true },
    delete: { icon: React.createElement(icons_1.KeyDelete, null), iconTitle: "Delete key" },
    enter: { icon: React.createElement(icons_1.KeyEnter, null), iconTitle: "Enter key" },
    meta: { icon: React.createElement(icons_1.KeyCommand, null), iconTitle: "Command key", isMacOnly: true },
    shift: { icon: React.createElement(icons_1.KeyShift, null), iconTitle: "Shift key", isMacOnly: true },
};
/** Reverse table of some CONFIG_ALIASES fields, for display by KeyComboTag */
exports.DISPLAY_ALIASES = {
    ArrowDown: "down",
    ArrowLeft: "left",
    ArrowRight: "right",
    ArrowUp: "up",
};
class KeyComboTagInternal extends common_1.AbstractPureComponent {
    constructor() {
        super(...arguments);
        this.renderKey = (key, index) => {
            var _a;
            const keyString = (_a = exports.DISPLAY_ALIASES[key]) !== null && _a !== void 0 ? _a : key;
            const icon = this.getKeyIcon(key);
            const reactKey = `key-${index}`;
            return (React.createElement("kbd", { className: (0, classnames_1.default)(common_1.Classes.KEY, { [common_1.Classes.MODIFIER_KEY]: icon != null }), key: reactKey },
                icon != null && React.createElement(icon_1.Icon, { icon: icon.icon, title: icon.iconTitle }),
                keyString));
        };
        this.renderMinimalKey = (key, index, isLastKey) => {
            const icon = this.getKeyIcon(key);
            if (icon == null) {
                return isLastKey ? key : React.createElement(React.Fragment, { key: `key-${index}` },
                    key,
                    "\u00A0+\u00A0");
            }
            return React.createElement(icon_1.Icon, { icon: icon.icon, title: icon.iconTitle, key: `key-${index}` });
        };
    }
    render() {
        const { className, combo, minimal, platformOverride } = this.props;
        const normalizedKeys = (0, hotkeyParser_1.normalizeKeyCombo)(combo, platformOverride);
        const keys = normalizedKeys
            .map(key => (key.length === 1 ? key.toUpperCase() : key))
            .map((key, index) => minimal
            ? this.renderMinimalKey(key, index, index === normalizedKeys.length - 1)
            : this.renderKey(key, index));
        return React.createElement("span", { className: (0, classnames_1.default)(common_1.Classes.KEY_COMBO, className, { [common_1.Classes.MINIMAL]: minimal }) }, keys);
    }
    getKeyIcon(key) {
        const { platformOverride } = this.props;
        const icon = KEY_ICONS[key];
        if ((icon === null || icon === void 0 ? void 0 : icon.isMacOnly) && !(0, hotkeyParser_1.isMac)(platformOverride)) {
            return undefined;
        }
        return icon;
    }
}
exports.KeyComboTagInternal = KeyComboTagInternal;
KeyComboTagInternal.displayName = `${common_1.DISPLAYNAME_PREFIX}.KeyComboTag`;
exports.KeyComboTag = KeyComboTagInternal;
//# sourceMappingURL=keyComboTag.js.map