"use strict";
/*
 * Copyright 2015 Palantir Technologies, Inc. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateTabIds = exports.TabTitle = void 0;
const tslib_1 = require("tslib");
const classnames_1 = tslib_1.__importDefault(require("classnames"));
const React = tslib_1.__importStar(require("react"));
const common_1 = require("../../common");
const props_1 = require("../../common/props");
const icon_1 = require("../icon/icon");
const tag_1 = require("../tag/tag");
class TabTitle extends common_1.AbstractPureComponent {
    constructor() {
        super(...arguments);
        this.handleClick = (e) => this.props.onClick(this.props.id, e);
    }
    render() {
        const { className, children, disabled, id, parentId, selected, title, icon, tagContent, tagProps, ...htmlProps } = this.props;
        const intent = selected ? common_1.Intent.PRIMARY : common_1.Intent.NONE;
        const { tabPanelId, tabTitleId } = generateTabIds(parentId, id);
        return (React.createElement("div", { ...(0, props_1.removeNonHTMLProps)(htmlProps), "aria-controls": tabPanelId, "aria-disabled": disabled, "aria-expanded": selected, "aria-selected": selected, className: (0, classnames_1.default)(common_1.Classes.TAB, className), "data-tab-id": id, id: tabTitleId, onClick: disabled ? undefined : this.handleClick, role: "tab", tabIndex: disabled ? undefined : selected ? 0 : -1 },
            icon != null && React.createElement(icon_1.Icon, { icon: icon, intent: intent, className: common_1.Classes.TAB_ICON }),
            title,
            children,
            tagContent != null && (React.createElement(tag_1.Tag, { minimal: true, intent: intent, ...tagProps, className: (0, classnames_1.default)(common_1.Classes.TAB_TAG, tagProps === null || tagProps === void 0 ? void 0 : tagProps.className) }, tagContent))));
    }
}
exports.TabTitle = TabTitle;
TabTitle.displayName = `${props_1.DISPLAYNAME_PREFIX}.TabTitle`;
function generateTabIds(parentId, tabId) {
    return {
        tabPanelId: `${common_1.Classes.TAB_PANEL}_${parentId}_${tabId}`,
        tabTitleId: `${common_1.Classes.TAB}-title_${parentId}_${tabId}`,
    };
}
exports.generateTabIds = generateTabIds;
//# sourceMappingURL=tabTitle.js.map